#!/usr/bin/env python
"""
sphinx-dehead
=============

- **Author:** Sean Wallitsch
- **Email:** sean@grenadehop.com
- **License:** MIT
- **Status:** Development
- **Python Versions:** 2.6-2.7

A script to extract the first found `<div class='section'>` from an HTML
document, then save that extracted element to it's own HTML file. Useful when
including an HTML file in another document, when you don't need all the header
junk.

Developed for including Sphinx built HTML documentation in an Octopress blog.

Usage
-----

sphinx-dehead takes a glob style input parameter, and an optional output
directory.

For example, this will dehead every HTML file in the current directory, and
save it to the default output directory, `dehead_output/`

.. code-block:: console

    $ sphinx-dehead './*.html'

While this will save it in the sibling `_docs` directory:

.. code-block:: console

    $ sphinx-dehead './*.html' -d ../_docs/

Installation
------------

sphinx-dehead can be installed with pip:

.. code-block:: console

    $ pip install sphinx-dehead

or by cloning the repository, and from the root directory calling:

.. code-block:: console

    $ python setup.py install


Public Functions
----------------

    main()
        Main script execution.

License
-------

The MIT License (MIT)

sphinx-dehead
Copyright (c) 2014 By Sean Wallitsch

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

"""

# =============================================================================
# IMPORTS
# =============================================================================

# Future Imports
from __future__ import print_function

# Standard Imports
from argparse import ArgumentParser
import codecs
from glob import glob
import os

# Third Party Imports
import bs4

# =============================================================================
# GLOBALS
# =============================================================================

__author__ = "Sean Wallitsch"
__author_email__ = "sean@grenadehop.com"
__copyright__ = "Copyright 2014, Sean Wallitsch"
__credits__ = ["Sean Wallitsch", ]
__license__ = "MIT"
__version__ = "0.2.1"
__module_name__ = "sphinx-dehead"
__short_desc__ = "A script to extract the main div section element from HTML"
__status__ = "Development"
__url__ = "http://github.com/shidarin/dehead"

# =============================================================================
# EXPORTS
# =============================================================================

__all__ = [
    'main'
]

# =============================================================================
# PRIVATE FUNCTIONS
# =============================================================================


def _get_input_files(input_arg):
    """Returns glob output of `input_arg`"""
    # Just grab any files specified, don't mess with provided patterns.
    files = glob(input_arg)

    # But only accept files that end in html.
    return [html_file for html_file in files if html_file.endswith('html')]

# =============================================================================


def _parse_args():
    """Uses argparse to parse command line arguments"""
    parser = ArgumentParser(description=__short_desc__)
    parser.add_argument(
        "input_files",
        help="the file(s) to be converted. Will do glob style pattern matching"
    )
    parser.add_argument(
        "-d",
        "--destination",
        help="specify an output directory to save converted files to. If not "
             "provided will default to ./dehead_output/"
    )

    args = parser.parse_args()

    if not args.destination:
        args.destination = './dehead_output/'

    return args

# =============================================================================
# PUBLIC FUNCTIONS
# =============================================================================


def main():
    """Main dehead script entry"""
    args = _parse_args()

    if not os.path.exists(args.destination):
        os.makedirs(args.destination)

    for html_file in _get_input_files(args.input_files):
        print("Reading file: {0}".format(html_file))
        with codecs.open(html_file, 'rb', 'utf-8') as html:
            soup = bs4.BeautifulSoup(html.read())

        section = soup.find('div', {'class': 'section'})

        if section:
            destination = os.path.join(args.destination, html_file)

            # Remove master heading, since we'll be including it elsewhere.
            title = section.find('h1')
            if title:
                title.extract()

            print("Writing file: {0}".format(destination))
            with codecs.open(destination, 'wb', 'utf-8') as export:
                export.write(section.prettify())
        else:
            print("No 'section' found in file: {0}".format(html_file))

# =============================================================================
# RUN
# =============================================================================

if __name__ == '__main__':
    try:
        main()
    except Exception as err:
        import traceback
        print('Unexpected error encountered:')
        print(err)
        print(traceback.format_exc())
        raw_input('Press enter key to exit')



#!/usr/bin/env python
"""

setup.py
========

This is a generic as possible setup.py template. The goal is to retrieve almost
all of the information from the main module file, rather than relying on values
explicitly entered here.

## Usage

This setup.py script needs to modified in the following ways:

- `MAIN_FILE` needs to be pointed at the main metadata file, this can be done
    easily by modifyng the second arg.
- `setup` kwargs need to be modified:
    - `classifiers` needs to be modified to suit your project.
    - `keywords` needs to be modified to suit your project.
- If you have files that need to be included (such as `LICENSE`, you need to
    create a MANIFEST.in file and `include FILENAME` them.

Other than that, all the metadata should live in your main file, just like
the example below.

## Metadata Example

The following should be placed in your project module's __init__.py file:
::
    __author__ = "Ivan Busquets"
    __author_email__ = "ivanbusquets@gmail.com"
    __copyright__ = "Copyright 2011, Ivan Busquets"
    __credits__ = ["Ivan Busquets", "Sean Wallitsch", ]
    __license__ = "MIT"
    __version__ = "1.2"
    __maintainer__ = "Sean Wallitsch"
    __maintainer_email__ = "sean@grenadehop.com"
    __module_name__ = "animatedSnap3D"
    __short_desc__ = "An extension to Nuke's 'snap' options for animated verts"
    __status__ = "Development"
    __url__ = 'http://github.com/ThoriumGroup/animatedSnap3D'

Note: At this time `credits` is unused.

"""
# ==============================================================================
# IMPORTS
# ==============================================================================

from setuptools import setup, find_packages
import codecs
import os
import re

# ==============================================================================
# GLOBALS
# ==============================================================================

HERE = os.path.abspath(os.path.dirname(__file__))
MAIN_FILE = os.path.join(HERE, 'sphinx_dehead', '__init__.py')

# Get the long description from the relevant file
with codecs.open('README.rst', encoding='utf-8') as readme_file:
    LONG_DESCRIPTION = readme_file.read()

# ==============================================================================
# PRIVATE FUNCTIONS
# ==============================================================================


def _find_metadata(filepath):
    """Reads all the metadata from a source file by opening manually.

    Why open and read it and not import?

    https://groups.google.com/d/topic/pypa-dev/0PkjVpcxTzQ/discussion

    Args:
        filepath : (str)
            Filepath to the file containing the metadata.

    Returns:
        {str: str}
            Dictionary with metadata keys and values.

    Raises:
        RuntimeError
            Cannot proceed if version or module_name not found

    """
    # Open in Latin-1 so that we avoid encoding errors.
    # Use codecs.open for Python 2 compatibility
    with codecs.open(filepath, 'r', 'latin1') as meta_file:
        metadata_file = meta_file.read()

    metadata = {}

    version_match = re.search(r"^__version__ = ['\"]([^'\"]*)['\"]",
                              metadata_file, re.M)
    author_match = re.search(r"^__author__ = ['\"]([^'\"]*)['\"]",
                             metadata_file, re.M)
    author_email_match = re.search(r"^__author_email__ = ['\"]([^'\"]*)['\"]",
                             metadata_file, re.M)
    copyright_match = re.search(r"^__copyright__ = ['\"]([^'\"]*)['\"]",
                                metadata_file, re.M)
    credits_match = re.search(r"^__credits__ = ['\"]([^'\"]*)['\"]",
                              metadata_file, re.M)
    license_match = re.search(r"^__license__ = ['\"]([^'\"]*)['\"]",
                              metadata_file, re.M)
    maint_match = re.search(r"^__maintainer__ = ['\"]([^'\"]*)['\"]",
                            metadata_file, re.M)
    maint_email_match = re.search(r"^__maintainer_email__ = ['\"]([^'\"]*)['\"]",
                            metadata_file, re.M)
    module_name_match = re.search(r"^__module_name__ = ['\"]([^'\"]*)['\"]",
                            metadata_file, re.M)
    short_desc_match = re.search(r"^__short_desc__ = ['\"]([^'\"]*)['\"]",
                             metadata_file, re.M)
    status_match = re.search(r"^__status__ = ['\"]([^'\"]*)['\"]",
                             metadata_file, re.M)
    url_match = re.search(r"^__url__ = ['\"]([^'\"]*)['\"]",
                             metadata_file, re.M)

    if not version_match or not module_name_match:
        raise RuntimeError("Unable to find version or module_name string.")

    if author_match:
        metadata['author'] = author_match.group(1)
    if author_email_match:
        metadata['author_email'] = author_email_match.group(1)
    if copyright_match:
        metadata['copyright'] = copyright_match.group(1)
    if credits_match:
        metadata['credits'] = credits_match.group(1)
    if license_match:
        metadata['license'] = license_match.group(1)
    if maint_match:
        metadata['maintainer'] = maint_match.group(1)
    if maint_email_match:
        metadata['maintainer_email'] = maint_email_match.group(1)
    if module_name_match:
        metadata['module_name'] = module_name_match.group(1)
    if short_desc_match:
        metadata['short_desc'] = short_desc_match.group(1)
    if status_match:
        metadata['status'] = status_match.group(1)
    if version_match:
        metadata['version'] = version_match.group(1)
    if url_match:
        metadata['url'] = url_match.group(1)

    return metadata

# ==============================================================================
# MAIN
# ==============================================================================

metadata = _find_metadata(MAIN_FILE)

setup(
    name=metadata['module_name'],
    version=metadata['version'],
    description=metadata.get('short_desc', ''),
    long_description=LONG_DESCRIPTION,

    # The project URL.
    url=metadata.get('url', ''),

    # Author & Maintainer details
    author=metadata.get('author', ''),
    author_email=metadata.get('author_email', ''),
    maintainer=metadata.get('maintainer', ''),
    maintainer_email=metadata.get('maintainer_email', ''),

    # Choose your license
    license=metadata.get('license', ''),

    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 3 - Alpha',

        # Indicate who your project is intended for
        'Environment :: Console',
        'Intended Audience :: End Users/Desktop',
        'Intended Audience :: Developers',
        'Topic :: Text Processing :: Markup :: HTML',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',

        # Pick your license as you wish (should match "license" above)
        'License :: OSI Approved :: MIT License',

        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: Implementation :: CPython',

        # OS
        'Operating System :: OS Independent',

        # Language
        'Natural Language :: English',
    ],

    # What does your project relate to?
    keywords='sphinx bootstrap octopress html rst partial',

    # You can just specify the packages manually here if your project is
    # simple. Or you can use find_packages.
    packages=find_packages(exclude=['tests']),

    # List run-time dependencies here.  These will be installed by pip when your
    # project is installed.
    install_requires=['argparse', 'beautifulsoup4'],

    # If there are data files included in your packages that need to be
    # installed, specify them here.  If using Python 2.6 or less, then these
    # have to be included in MANIFEST.in as well.
    package_data={},
    include_package_data=True,

    # Targeted OS
    platforms='any',

    # To provide executable scripts, use entry points in preference to the
    # "scripts" keyword. Entry points provide cross-platform support and allow
    # pip to create the appropriate form of executable for the target platform.
    entry_points={
        'console_scripts': [
            'sphinx-dehead=sphinx_dehead:main',
        ],
    },
)
